// an Edge represents a directed link between two nodes in a Graph

public class Edge {

    // instance variables
    private Vertex start;     // source vertex of edge
    private Vertex end;       // destination vertex of edge
    private boolean labeled;  // does the edge have a cost value?
    private double cost;      // the cost value of the edge

    // constructor for an unlabeled edge
    public Edge(Vertex u, Vertex v) {
        this.start = u;
        this.end = v;
        this.labeled = false;
        this.cost = 0;
    }

    // constructor for a labeled edge
    public Edge(Vertex u, Vertex v, double cost) {
        this.start = u;
        this.end = v;
        this.labeled = true;
        this.cost = cost;
    }

    // returns a string representation of the edge
    public String toString() {
        if (this.labeled) {
            return String.format("Edge: %s--%.1f-->%s", start, cost, end);
        } else {
            return String.format("Edge: %s--->%s", start, end);
        }
    }

    // returns the edge's start vertex
    public Vertex startVertex() {
        return this.start;
    }

    // returns the edge's end vertex
    public Vertex endVertex() {
        return this.end;
    }

    // returns the edge's cost value
    public double getCost() {
        return this.cost;
    }
}
