// a Vertex represents a node in a Graph

import java.util.*;

public class Vertex {
    //----------------------------------------------------------------------
    // new instance variables
    private double x, y;

    // new constructor
    public Vertex(String label, double x, double y) {
        this(label);
        this.x = x;
        this.y = y;
    }
    // new methods
    public double getX() { return this.x; }
    public double getY() { return this.y; }
    public Vertex getPredecessor() { return null; }
    //----------------------------------------------------------------------

    // instance variables
    private String label;              // vertex label
    private List<Edge> outgoingEdges;  // edges to adjacent vertices
    private boolean visited;           // used when traversing the graph

    // constructor
    public Vertex(String label) {
        this.label = label;
        this.outgoingEdges = new ArrayList<Edge>();
        this.visited = false;
    }

    // returns a printable representation of the vertex
    public String toString() {
        return this.label;
    }

    // returns the vertex's label
    public String getLabel() {
        return this.label;
    }

    // returns true if this vertex has been visited
    public boolean visited() {
        return this.visited;
    }

    // updates the visited status of this vertex
    public void setVisited(boolean newValue) {
        this.visited = newValue;
    }

    // returns a list of the outgoing edges
    public List<Edge> outgoingEdges() {
        return this.outgoingEdges;
    }

    // adds a new edge to the list of outgoing edges
    public void addOutgoingEdge(Edge e) {
        this.outgoingEdges.add(e);
    }

    // returns a list of all neighboring vertices
    public List<Vertex> adjacentVertices() {
        List<Vertex> neighbors = new ArrayList<Vertex>();
        for (Edge e : this.outgoingEdges) {
            neighbors.add(e.endVertex());
        }
        return neighbors;
    }
}
